@@ -18,7 +18,7 @@ class Explorer(TemplateView):
 
     def dispatch(self, request, *args, **kwargs):
         if not request.user.is_authenticated:
-            return http.HttpResponseRedirect(f'/admin/login/?next={reverse("explorer-main")}')
+            return http.HttpResponseRedirect(f'{reverse("explorer-login")}?next={reverse("explorer-main")}')
         return super().dispatch(request, *args, **kwargs)
 
     def get(self, request, *args, **kwargs):
