@@ -15,4 +15,11 @@ def is_path_exists(*args):
             path = arg
             continue
         path = os.path.join(path, arg)
-    return os.path.exists(path)
\ No newline at end of file
+    return os.path.exists(path)
+
+def is_path_contain_reverse(path):
+    """Checking weather the path contain ../"""
+    split_path = path.split(os.path.sep)
+    if '..' in split_path:
+        return False
+    return True
\ No newline at end of file
